@@ -1,7 +1,7 @@
 (*
  * libbrlapi - A library providing access to braille terminals for applications.
  *
- * Copyright (C) 2002-2018 by
+ * Copyright (C) 2002-2021 by
  *   Sébastien Hinderer <Sebastien.Hinderer@ens-lyon.org>
  *   Samuel Thibault <Samuel.Thibault@ens-lyon.org>
  * All rights reserved.
@@ -13,7 +13,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  *)
@@ -110,6 +110,8 @@ external closeConnection :
   ?h:handle -> unit -> unit = "brlapiml_closeConnection"
 external getDriverName :
   ?h:handle -> unit -> string = "brlapiml_getDriverName"
+external getModelIdentifier :
+  ?h:handle -> unit -> string = "brlapiml_getModelIdentifier"
 external getDisplaySize :
   ?h:handle -> unit -> int * int = "brlapiml_getDisplaySize"
 
@@ -133,6 +135,8 @@ external readKey :
   ?h:handle -> unit -> int64 option = "brlapiml_readKey"
 external waitKey :
   ?h:handle -> unit -> int64 = "brlapiml_waitKey"
+external readKeyWithTimeout :
+  ?h:handle -> int -> int64 option = "brlapiml_readKeyWithTimeout"
 
 type expandedKeyCode = {
   type_ : int32;
