@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2016 by The BRLTTY Developers.
+ * Copyright (C) 1995-2021 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -30,22 +30,31 @@ typedef enum {
   HT_MODEL_EasyBraille         = 0X44,
   HT_MODEL_ActiveBraille       = 0X54,
   HT_MODEL_ConnectBraille40    = 0X55,
+  HT_MODEL_Actilino            = 0X61,
   HT_MODEL_ActiveStar40        = 0X64,
-  HT_MODEL_BasicBraille16      = 0X81,
-  HT_MODEL_BasicBraille20      = 0X82,
-  HT_MODEL_BasicBraille32      = 0X83,
-  HT_MODEL_BasicBraille40      = 0X84,
-  HT_MODEL_BasicBraille48      = 0X8A,
-  HT_MODEL_BasicBraille64      = 0X86,
-  HT_MODEL_BasicBraille80      = 0X87,
-  HT_MODEL_BasicBraille160     = 0X8B,
   HT_MODEL_Braillino           = 0X72,
   HT_MODEL_BrailleStar40       = 0X74,
   HT_MODEL_BrailleStar80       = 0X78,
   HT_MODEL_Modular20           = 0X80,
+  HT_MODEL_BasicBraille16      = 0X81,
+  HT_MODEL_BasicBraille20      = 0X82,
+  HT_MODEL_BasicBraille32      = 0X83,
+  HT_MODEL_BasicBraille40      = 0X84,
+  HT_MODEL_BasicBraille64      = 0X86,
+  HT_MODEL_BasicBraille80      = 0X87,
   HT_MODEL_Modular80           = 0X88,
   HT_MODEL_Modular40           = 0X89,
-  HT_MODEL_Bookworm            = 0X90
+  HT_MODEL_BasicBraille48      = 0X8A,
+  HT_MODEL_BasicBraille160     = 0X8B,
+  HT_MODEL_Bookworm            = 0X90,
+  HT_MODEL_BasicBraillePlus20  = 0X92,
+  HT_MODEL_BasicBraillePlus32  = 0X93,
+  HT_MODEL_BasicBraillePlus40  = 0X94,
+  HT_MODEL_BasicBraillePlus64  = 0X96,
+  HT_MODEL_BasicBraillePlus80  = 0X97,
+  HT_MODEL_BasicBraillePlus48  = 0X9A,
+  HT_MODEL_BasicBraillePlus84  = 0X9C,
+  HT_MODEL_Activator           = 0XA4
 } HT_ModelIdentifier;
 
 /* Packet definition */
@@ -195,6 +204,13 @@ typedef enum {
   /* Braille star keys */
   HT_KEY_SpaceRight = 0X18,
 
+  /* Actilino keys */
+  HT_KEY_JoystickLeft       = 0X74,
+  HT_KEY_JoystickRight      = 0X75,
+  HT_KEY_JoystickUp         = 0X76,
+  HT_KEY_JoystickDown       = 0X77,
+  HT_KEY_JoystickAction     = 0X78,
+
   /* ranges and flags */
   HT_KEY_ROUTING = 0X20,
   HT_KEY_STATUS = 0X70,
