@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2018 by The BRLTTY Developers.
+ * Copyright (C) 1995-2021 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -1849,7 +1849,7 @@ startLatchMonitor (BrailleDisplay *brl) {
   if (!brl->data->latch.delay) return 1;
 
   if (asyncNewRelativeAlarm(&brl->data->latch.monitor, 0, irMonitorLatch, brl)) {
-    if (asyncResetAlarmEvery(brl->data->latch.monitor, brl->data->latch.interval)) {
+    if (asyncResetAlarmInterval(brl->data->latch.monitor, brl->data->latch.interval)) {
       brl->data->latch.pulled = 0;
       return 1;
     }
