@@ -2,16 +2,16 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2017 by The BRLTTY Developers.
+ * Copyright (C) 1995-2021 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
  * This is free software, placed under the terms of the
- * GNU General Public License, as published by the Free Software
- * Foundation; either version 2 of the License, or (at your option) any
- * later version. Please see the file LICENSE-GPL for details.
+ * GNU Lesser General Public License, as published by the Free Software
+ * Foundation; either version 2.1 of the License, or (at your option) any
+ * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -28,17 +28,14 @@ extern "C" {
 #endif /* __cplusplus */
 
 extern FILE *getConsole (void);
-extern int writeConsole (const unsigned char *bytes, size_t count);
-extern int ringBell (void);
+extern int writeToConsole (const unsigned char *bytes, size_t count);
+extern int ringConsoleBell (void);
 
 extern const char *getDeviceDirectory (void);
 extern char *getDevicePath (const char *device);
-extern const char *resolveDeviceName (const char *const *names, const char *description);
+extern const char *resolveDeviceName (const char *const *names, int strict, const char *description);
 
 #define DEVICE_PARAMETER_SEPARATOR '+'
-
-extern int isQualifiedDevice (const char **identifier, const char *qualifier);
-extern int isUnqualifiedDevice (const char *identifier);
 extern char **getDeviceParameters (const char *const *names, const char *identifier);
 
 #undef ALLOW_DOS_DEVICE_NAMES
