@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2018 by The BRLTTY Developers.
+ * Copyright (C) 1995-2021 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -11,7 +11,7 @@
  * Foundation; either version 2.1 of the License, or (at your option) any
  * later version. Please see the file LICENSE-LGPL for details.
  *
- * Web Page: http://brltty.com/
+ * Web Page: http://brltty.app/
  *
  * This software is maintained by Dave Mielke <dave@mielke.cc>.
  */
@@ -57,14 +57,8 @@ extern int connectSocket (
   int timeout
 );
 
-static inline int
-getSocketOption (
-  SocketDescriptor socketDescriptor,
-  int level, int option,
-  void *value, socklen_t *length
-) {
-  return getsockopt(socketDescriptor, level, option, value, length);
-}
+extern int setSocketLingerTime (SocketDescriptor socketDescriptor, int seconds);
+extern int setSocketNoLinger (SocketDescriptor socketDescriptor);
 #endif /* GOT_SOCKETS */
 
 extern int changeOpenFlags (FileDescriptor fileDescriptor, int flagsToClear, int flagsToSet);
