@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2021 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -32,6 +32,8 @@ typedef struct {
 
 typedef int GioDisconnectResourceMethod (GioHandle *handle);
 
+typedef const char *MakeResourceIdentifierMethod (GioHandle *handle, char *buffer, size_t size);
+
 typedef char *GioGetResourceNameMethod (GioHandle *handle, int timeout);
 
 typedef ssize_t GioWriteDataMethod (GioHandle *handle, const void *data, size_t size, int timeout);
@@ -88,6 +90,7 @@ typedef void *GioGetResourceObjectMethod (GioHandle *handle);
 typedef struct {
   GioDisconnectResourceMethod *disconnectResource;
 
+  MakeResourceIdentifierMethod *makeResourceIdentifier;
   GioGetResourceNameMethod *getResourceName;
 
   GioWriteDataMethod *writeData;
