@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2021 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -25,7 +25,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-extern int writeBrailleWindow (BrailleDisplay *brl, const wchar_t *text);
+extern int writeBrailleWindow (BrailleDisplay *brl, const wchar_t *text, unsigned char quality);
 extern void reportBrailleWindowMoved (void);
 
 extern void scheduleUpdate (const char *reason);
