@@ -20,6 +20,7 @@
 #define BRLTTY_INCLUDED_USB_SERIAL
 
 #include "io_usb.h"
+#include "io_log.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -33,17 +34,27 @@ typedef struct {
 } UsbSerialAdapter;
 
 extern const UsbSerialAdapter *usbFindSerialAdapter (const UsbDeviceDescriptor *descriptor);
-
-extern int usbSkipInitialBytes (UsbInputFilterData *data, unsigned int count);
-
 extern const UsbSerialOperations usbSerialOperations_CDC_ACM;
 extern const UsbSerialOperations usbSerialOperations_Belkin;
+extern const UsbSerialOperations usbSerialOperations_CH341;
 extern const UsbSerialOperations usbSerialOperations_CP2101;
 extern const UsbSerialOperations usbSerialOperations_CP2110;
 extern const UsbSerialOperations usbSerialOperations_FTDI_SIO;
 extern const UsbSerialOperations usbSerialOperations_FTDI_FT8U232AM;
 extern const UsbSerialOperations usbSerialOperations_FTDI_FT232BM;
 
+extern UsbSerialData *usbGetSerialData (UsbDevice *devic3e);
+extern int usbSkipInitialBytes (UsbInputFilterData *data, unsigned int count);
+
+static inline int
+usbUpdateByte (uint8_t *byte, uint8_t mask, uint8_t value) {
+  if ((*byte & mask) == value) return 0;
+
+  *byte &= ~mask;
+  *byte |= value;
+  return 1;
+}
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
