@@ -24,21 +24,21 @@ nsisName="NSIS"
 nsisLocation="/c/Program Files (x86)/NSIS"
 nsisDownload="http://nsis.sourceforge.net/"
 
-libusb0Name="LibUSB-Win32"
+libusb0Name="LibUSB (aka LibUSB-Win32)"
 libusb0Version="1.2.6.0"
 libusb0Location="/c/LibUSB-Win32"
 libusb0Files="bin/libusb-win32-bin-README.txt"
 libusb0Download="http://libusb-win32.sourceforge.net/"
 libusb0Pattern="usb0"
 
-libusb1Name="LibUSB-1.0"
+libusb1Name="LibUSB-1.0 (aka LibUSBx)"
 libusb1Version="1.0.18"
 libusb1Location="/c/LibUSB-1.0"
 libusb1Files="libusb-1.0.def"
 libusb1Download="http://www.libusb.org/wiki/windows_backend"
 libusb1Pattern="usb-1.0"
 
-winusbName="WinUSB"
+winusbName="LibUSB-1.0 WinUSB Coinstallers"
 winusbLocation="/c/WinUSB"
 winusbFiles="libusb_device.inf"
 winusbDownload="http://www.libusb.org/wiki/windows_backend"
